<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * AZONCustomList starts here. Manager sets mode, adds required wp hooks and loads required object of structure
 *
 * Manager controls and access to all modules and classes of AZONCustomList.
 *
 * @package AZONCustomList
 * @since   1.0
 */
class AZONCustomList {

	/**
	 * Constructor loads API functions, defines paths and adds required wp actions
	 *
	 * @since  1.0
	 */
	public function __construct() 
	{
		add_action( 'init', array( $this, 'init' ), 9 );
	}

	/**
	 * Callback function for WP init action hook. Sets AZONCustomList mode and loads required objects.
	 *
	 * @since  1.0
	 * @access public
	 *
	 * @return void
	 */
	public function init() 
	{
		do_action( 'AZONCustomList_before_init' );
		
		global $wpdb;
		$this->db = $wpdb;

		if( is_admin() ){
			$this->editor_assets();
		}
		else{
			$this->frontend_assets();
		}
		
		do_action( 'AZONCustomList_after_init' );
	}

	public function frontend_assets()
	{
		wp_enqueue_style(
			'azon/custom-list-view',
			plugins_url( 'frontend/frontend.view.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_style(
			'azon/custom-font',
			plugins_url( '../assets/fonts/iconmoon.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_script(
			'azon/custom-list-view',
			plugins_url( 'frontend/frontend.build.js', __FILE__ ),
			array( 'wp-element')
	  	);

	  	wp_localize_script( 'azon/custom-list-view', 'AZON', array(
			'assets_url' => AZON_BLOCK_URL,
			'google_fonts' => array()
		) );
	}
	
	public function editor_assets()
	{
		wp_enqueue_script(
			'azon/custom-list',
			plugins_url( 'backend/backend.build.js', __FILE__ ),
			array( 'wp-blocks', 'wp-element', 'wp-editor' )
	  	);

	  	wp_enqueue_style(
			'azon/custom-font',
			plugins_url( '../assets/fonts/iconmoon.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_enqueue_style(
			'azon/custom-list',
			plugins_url( 'backend/backend.editor.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);
		
		wp_enqueue_style(
			'azon/custom-list-view',
			plugins_url( 'frontend/frontend.view.css', __FILE__ ),
			array( 'wp-edit-blocks' )
		);

		wp_localize_script( 'azon/custom-list', 'AZON', array(
			'ajax_url' => apply_filters( 'AZONCustomList_ref', admin_url('admin-ajax.php?action=YVYAjaxRequest') ),
			'assets_url' => AZON_BLOCK_URL,
			'google_fonts' => array()
		) );
	}
}

/**
 * Main AZONCustomList manager.
 * @var AZONCustomList $AZONCustomList - instance of composer management.
 * @since 1.0
 */
global $AZONCustomList;
$AZONCustomList = new AZONCustomList();

function AZONCustomList(){
	global $AZONCustomList;

	return $AZONCustomList;
}